function printparetodiff(base, heuristic, file)
%PRINTPARETODIFF Outputs an overlay image of two pareto sets
%   PRINTPARETODIFF(BASE, HEURISTIC, FILE) Outputs an image
%   with basename FILE overlapping the ground truth pareto
%   surface BASE (with lines) over a heuristically determined
%   pareto surface HEURISTIC.
%   Output is in two files which should be plotted at the
%   same location, the one ending in _cube.eps first.

if nargin ~= 3
  error('Invalid number of arguments');
end

h = figure;
set(h, 'visible', 'off');

wires = pareto2cube(base, 'outside', 0, 'k');
cube  = pareto2cube(heuristic, 'outside');
axis tight;

set(wires, 'visible', 'off');
set(cube, 'visible', 'on');
print(1, [file '_cube.eps'], '-depsc2', '-painters', '-loose')

set(wires, 'visible', 'on');
set(cube, 'visible', 'off');

axis off
title('');
set(1, 'InvertHardcopy', 'off');
set(1, 'Color', 'None');
print(1, [file '_lines.eps'], '-depsc2', '-painters', '-loose')

close(h)
